# django-xently

Packages [django-oscar][django-oscar-url]-style dynamic class loading logic for in django based projects.

[django-oscar-url]: https://github.com/django-oscar/django-oscar "django-oscar"